# Change log

## [v0.3.0](https://github.com/cofiem/music-playlists/releases/tag/v0.3.0)

Released 2026-01-17

- Add docs generation
- Add Python 3.14 support.
- Allow providing all config in one file.
- Update dependencies.

## [v0.2.0](https://github.com/cofiem/music-playlists/releases/tag/v0.2.0)

Released 2025-07-05

- Add cli commands to list config and playlist tracks.
- Introduce release publish via PyPI Trusted Publishing.
- Add GitHub Actions for checking coverage, Actions security, test coverage, linters.
- Lots of minor code updates to satisfy linters.
- Migrate to hatch.
